import codecs
import os
from setuptools import setup, find_packages

# these things are needed for the README.md show on pypi (if you dont need delete it)
here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

# you need to change all these
VERSION = '0.1.1'
DESCRIPTION = 'Machine Learning and Graph based tool for detecting and analyzing Bone-Muscle Interactions'
LONG_DESCRIPTION = 'Machine Learning and Graph based tool for detecting and analyzing Bone-Muscle Interactions'

from setuptools import setup, find_packages

setup(
    name="BMINet",
    version=VERSION,
    author="Spencer Wang",
    author_email="jrwangspencer@stu.suda.edu.cn",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    url='https://github.com/Spencer-JRWang/BMINet',
    packages=find_packages(),
    install_requires=[
        "anyio==4.4.0",
        "argon2-cffi==23.1.0",
        "argon2-cffi-bindings==21.2.0",
        "arrow==1.3.0",
        "async-lru==2.0.4",
        "attrs==24.2.0",
        "babel==2.16.0",
        "beautifulsoup4==4.12.3",
        "bleach==6.1.0",
        # "blinker==1.8.2",
        "catboost==1.2.5",
        "certifi==2024.8.30",
        "cffi==1.17.1",
        "charset-normalizer==3.3.2",
        # "click==8.1.7",
        "cloudpickle==3.0.0",
        "python-louvain==0.16",
        "contourpy==1.3.0",
        "cycler==0.12.1",
        "defusedxml==0.7.1",
        "fastjsonschema==2.20.0",
        # "Flask==3.0.3",
        "fonttools==4.53.1",
        "fqdn==1.5.1",
        "graphviz==0.20.3",
        "h11==0.14.0",
        "httpcore==1.0.5",
        "httpx==0.27.2",
        # "idna==3.8",
        "ipywidgets==8.1.5",
        "isoduration==20.11.0",
        # "itsdangerous==2.2.0",
        # "Jinja2==3.1.4",
        "joblib==1.4.2",
        "json5==0.9.25",
        "jsonpointer==3.0.0",
        "jsonschema==4.23.0",
        "jsonschema-specifications==2023.12.1",
        "jupyter==1.1.1",
        "jupyter-console==6.6.3",
        "jupyter-events==0.10.0",
        "jupyter-lsp==2.2.5",
        "jupyter_server==2.14.2",
        "jupyter_server_terminals==0.5.3",
        "jupyterlab==4.2.5",
        "jupyterlab_pygments==0.3.0",
        "jupyterlab_server==2.27.3",
        "jupyterlab_widgets==3.0.13",
        "kiwisolver==1.4.5",
        "lightgbm==4.5.0",
        "llvmlite==0.43.0",
        "MarkupSafe==2.1.5",
        "matplotlib==3.9.2",
        "mistune==3.0.2",
        "nbclient==0.10.0",
        "nbconvert==7.16.4",
        "nbformat==5.10.4",
        "networkx==3.3",
        "notebook==7.2.2",
        "notebook_shim==0.2.4",
        "numba==0.60.0",
        "numpy==1.26.0",
        "overrides==7.7.0",
        "pandas==2.2.2",
        "pandocfilters==1.5.1",
        "pillow==10.4.0",
        "plotly==5.24.0",
        "prometheus_client==0.20.0",
        "pycparser==2.22",
        "pyparsing==3.1.4",
        "python-json-logger==2.0.7",
        "pytz==2024.1",
        "PyYAML==6.0.2",
        "referencing==0.35.1",
        "requests==2.32.3",
        "rfc3339-validator==0.1.4",
        "rfc3986-validator==0.1.1",
        "rpds-py==0.20.0",
        "scikit-learn==1.4.0",
        "scipy==1.14.1",
        "seaborn==0.13.2",
        "Send2Trash==1.8.3",
        "setuptools==73.0.1",
        "shap==0.46.0",
        "slicer==0.0.8",
        "sniffio==1.3.1",
        "soupsieve==2.6",
        "tenacity==9.0.0",
        "terminado==0.18.1",
        "threadpoolctl==3.5.0",
        "tinycss2==1.3.0",
        "tqdm==4.66.5",
        "types-python-dateutil==2.9.0.20240906",
        "tzdata==2024.1",
        "uri-template==1.3.0",
        "urllib3==2.2.2",
        "webcolors==24.8.0",
        "webencodings==0.5.1",
        "websocket-client==1.8.0",
        # "Werkzeug==3.0.4",
        "wheel==0.44.0",
        "widgetsnbextension==4.0.13",
        "xgboost==2.1.1"
    ],
    include_package_data=True,
    package_data={
        'BMINet': ['Interaction/*.txt', 'Model/*.txt'],
    },
    keywords=['python', 'BMINet', 'Interaction', 'Network', 'Bone-Muscle', 'windows', 'mac', 'linux'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires='>=3.9',
)

